guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/08: gnu: lcov: Patch reference to 'find' command.


From: guix-commits
Subject: 01/08: gnu: lcov: Patch reference to 'find' command.
Date: Mon, 22 May 2023 11:11:44 -0400 (EDT)

civodul pushed a commit to branch master
in repository guix.

commit 88a2871d8f82a7280486c2a30cc9b510ee8b2b5c
Author: Ludovic Courtès <ludovic.courtes@inria.fr>
AuthorDate: Mon May 22 12:11:01 2023 +0200

    gnu: lcov: Patch reference to 'find' command.
    
    Fixes <https://issues.guix.gnu.org/63517>.
    Reported by Luca Cirrottola <luca.cirrottola@inria.fr>.
    
    * gnu/packages/code.scm (lcov)[arguments]: Rename 'patch-pwd' phase to
    'patch-references-to-commands', and patch reference to 'find'.
---
 gnu/packages/code.scm | 15 +++++++++------
 1 file changed, 9 insertions(+), 6 deletions(-)

diff --git a/gnu/packages/code.scm b/gnu/packages/code.scm
index d57954c47c..9cdda2b751 100644
--- a/gnu/packages/code.scm
+++ b/gnu/packages/code.scm
@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013, 2015, 2018, 2020, 2021 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2015, 2018, 2020, 2021, 2023 Ludovic Courtès 
<ludo@gnu.org>
 ;;; Copyright © 2013, 2015 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2015, 2018 Ricardo Wurmus <rekado@elephly.net>
 ;;; Copyright © 2016, 2017, 2019-2023 Efraim Flashner <efraim@flashner.co.il>
@@ -562,16 +562,19 @@ stack traces.")
                                          (assoc-ref %outputs "out")))
        #:phases
        (modify-phases %standard-phases
-         (add-after 'unpack 'patch-pwd
-           ;; Lift the requirement of having a shell in PATH.
-           (lambda _
+         (add-after 'unpack 'patch-references-to-commands
+           (lambda* (#:key inputs #:allow-other-keys)
+             ;; Lift the requirement of having a shell and 'find' in PATH.
              (substitute* "bin/geninfo"
                (("qw/abs_path/")
                 "qw/abs_path getcwd/"))
              (substitute* '("bin/lcov" "bin/geninfo")
                (("`pwd`")
-                "getcwd()"))
-             #t))
+                "getcwd()")
+               (("`find ")
+                (string-append "`"
+                               (search-input-file inputs "/bin/find")
+                               " ")))))
          (delete 'configure)            ;no configure script
          (add-after 'install 'wrap
            (lambda* (#:key outputs #:allow-other-keys)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]